@@ -107,8 +107,8 @@ struct config_file_data_ipmi_fru
 {
   unsigned int verbose_count;
   int verbose_count_count;
-  int skip_checks;              /* legacy - parse for backwards compatability */
-  int skip_checks_count;        /* legacy - parse for backwards compatability */
+  int skip_checks;              /* legacy - parse for backwards compatibility */
+  int skip_checks_count;        /* legacy - parse for backwards compatibility */
   int bridge_fru;
   int bridge_fru_count;
   int interpret_oem_data;
@@ -165,8 +165,8 @@ struct config_file_data_ipmi_sel
   int output_event_state_count;
   char *event_state_config_file;
   int event_state_config_file_count;
-  int assume_system_event_records; /* legacy - parse for backwards compatability */
-  int assume_system_event_records_count; /* legacy - parse for backwards compatability */
+  int assume_system_event_records; /* legacy - parse for backwards compatibility */
+  int assume_system_event_records_count; /* legacy - parse for backwards compatibility */
   int interpret_oem_data;
   int interpret_oem_data_count;
   int output_oem_event_strings;
