@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2007-2014 FreeIPMI Core Team
- * 
+ * Copyright (C) 2007-2015 FreeIPMI Core Team
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #if HAVE_CONFIG_H
@@ -158,7 +158,7 @@ get_chassis_capabilities (ipmi_chassis_state_data_t *state_data)
       goto cleanup;
     }
   sdr_device_address = val;
- 
+
   pstdout_printf (state_data->pstate,
                   "SDR Device Address      : %Xh\n",
                   sdr_device_address);
@@ -342,7 +342,7 @@ get_chassis_status (ipmi_chassis_state_data_t *state_data)
 
   pstdout_printf (state_data->pstate,
                   "Power restore policy                : %s\n",
-		  str);
+                  str);
 
   temp_val = IPMI_LAST_POWER_EVENT_UNKNOWN;
 
@@ -443,8 +443,8 @@ get_chassis_status (ipmi_chassis_state_data_t *state_data)
     }
 
   pstdout_printf (state_data->pstate,
-		  "Last Power Event                    : %s\n",
-		  str);
+                  "Last Power Event                    : %s\n",
+                  str);
 
   if (FIID_OBJ_GET (obj_cmd_rs, "misc_chassis_state.chassis_intrusion_active", &val) < 0)
     {
@@ -539,7 +539,7 @@ get_chassis_status (ipmi_chassis_state_data_t *state_data)
 
       pstdout_printf (state_data->pstate,
                       "Chassis Identify state              : %s\n",
-		      str);
+                      str);
 
     }
 
@@ -764,7 +764,8 @@ set_power_restore_policy (ipmi_chassis_state_data_t *state_data)
   if (args->set_power_restore_policy_arg == IPMI_POWER_RESTORE_POLICY_NO_CHANGE)
     {
       char policy_supported[100];
-      memset (policy_supported, 0, sizeof (policy_supported));
+
+      memset (policy_supported, '\0', sizeof (policy_supported));
 
       if (FIID_OBJ_GET (obj_cmd_rs, "powered_off_after_ac_mains_returns", &val) < 0)
         {
@@ -924,7 +925,7 @@ get_system_restart_cause (ipmi_chassis_state_data_t *state_data)
     default:
       restart_cause_str = "unknown";
     }
-  
+
   pstdout_printf (state_data->pstate,
                   "Restart cause : %s\n",
                   restart_cause_str);
@@ -1173,7 +1174,7 @@ get_boot_flags (ipmi_chassis_state_data_t *state_data)
   pstdout_printf (state_data->pstate,
                   "Console redirection control   : %s\n",
                   str);
-  
+
   if (FIID_OBJ_GET (obj_cmd_rs, "lock_out_sleep_button", &val) < 0)
     {
       pstdout_fprintf (state_data->pstate,
@@ -1263,7 +1264,7 @@ get_boot_flags (ipmi_chassis_state_data_t *state_data)
     str = "Default";
   else
     str = "unknown";
-  
+
   pstdout_printf (state_data->pstate,
                   "Firmware BIOS verbosity level : %s\n",
                   str);
@@ -1606,7 +1607,7 @@ run_cmd_args (ipmi_chassis_state_data_t *state_data)
 
   if (args->get_chassis_capabilities)
     return (get_chassis_capabilities (state_data));
-            
+
   if (args->get_chassis_status)
     return (get_chassis_status (state_data));
 
@@ -1616,18 +1617,18 @@ run_cmd_args (ipmi_chassis_state_data_t *state_data)
   if (args->chassis_identify)
     return (chassis_identify (state_data));
 
-  /* All chassis "set" operations are legacy, see ipmi-config for chassis configuration */ 
+  /* All chassis "set" operations are legacy, see ipmi-config for chassis configuration */
   if (args->set_power_restore_policy)
     return (set_power_restore_policy (state_data));
 
-  /* All chassis "set" operations are legacy, see ipmi-config for chassis configuration */ 
+  /* All chassis "set" operations are legacy, see ipmi-config for chassis configuration */
   if (args->set_power_cycle_interval)
     return (set_power_cycle_interval (state_data));
 
   if (args->get_system_restart_cause)
     return (get_system_restart_cause (state_data));
 
-  /* All chassis "set" operations are legacy, see ipmi-config for chassis configuration */ 
+  /* All chassis "set" operations are legacy, see ipmi-config for chassis configuration */
   if (args->set_system_boot_options)
     return (set_boot_flags (state_data));
 
@@ -1662,7 +1663,8 @@ _ipmi_chassis (pstdout_state_t pstate,
   if (!(state_data.ipmi_ctx = ipmi_open (prog_data->progname,
                                          hostname,
                                          &(prog_data->args->common_args),
-					 state_data.pstate)))
+                                         state_data.pstate,
+                                         0)))
     goto cleanup;
 
   if (run_cmd_args (&state_data) < 0)
@@ -1685,14 +1687,12 @@ main (int argc, char **argv)
 
   ipmi_disable_coredump ();
 
-  memset (&prog_data, '\0', sizeof (ipmi_chassis_prog_data_t));
   prog_data.progname = argv[0];
   ipmi_chassis_argp_parse (argc, argv, &cmd_args);
-
   prog_data.args = &cmd_args;
 
   if ((hosts_count = pstdout_setup (&(prog_data.args->common_args.hostname),
-				    &(prog_data.args->common_args))) < 0)
+                                    &(prog_data.args->common_args))) < 0)
     return (EXIT_FAILURE);
 
   if (!hosts_count)
