@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2003-2015 FreeIPMI Core Team
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -81,13 +81,13 @@ fiid_template_t tmpl_ssif_raw =
 
 static void
 _api_ssif_dump (ipmi_ctx_t ctx,
-		const void *pkt,
-		unsigned int pkt_len,
-		uint8_t cmd,
-		uint8_t net_fn,
-		uint8_t group_extension,
-		unsigned int debug_direction,
-		fiid_template_t tmpl_cmd)
+                const void *pkt,
+                unsigned int pkt_len,
+                uint8_t cmd,
+                uint8_t net_fn,
+                uint8_t group_extension,
+                unsigned int debug_direction,
+                fiid_template_t tmpl_cmd)
 {
   char hdrbuf[DEBUG_UTIL_HDR_BUFLEN];
 
@@ -105,10 +105,10 @@ _api_ssif_dump (ipmi_ctx_t ctx,
                  debug_direction,
                  net_fn,
                  cmd,
-		 group_extension,
+                 group_extension,
                  hdrbuf,
                  DEBUG_UTIL_HDR_BUFLEN);
-  
+
   ipmi_dump_ssif_packet (STDERR_FILENO,
                          NULL,
                          hdrbuf,
@@ -120,90 +120,89 @@ _api_ssif_dump (ipmi_ctx_t ctx,
 
 static void
 _api_ssif_dump_rq (ipmi_ctx_t ctx,
-		   const void *pkt,
-		   unsigned int pkt_len,
-		   uint8_t cmd,
-		   uint8_t net_fn,
-		   uint8_t group_extension,
-		   fiid_obj_t obj_cmd_rq)
+                   const void *pkt,
+                   unsigned int pkt_len,
+                   uint8_t cmd,
+                   uint8_t net_fn,
+                   uint8_t group_extension,
+                   fiid_obj_t obj_cmd_rq)
 {
   fiid_field_t *tmpl_cmd = NULL;
 
   if ((tmpl_cmd = fiid_obj_template (obj_cmd_rq)))
     {
       _api_ssif_dump (ctx,
-		      pkt,
-		      pkt_len,
-		      cmd,
-		      net_fn,
-		      group_extension,
-		      DEBUG_UTIL_DIRECTION_REQUEST,
-		      tmpl_cmd);
+                      pkt,
+                      pkt_len,
+                      cmd,
+                      net_fn,
+                      group_extension,
+                      DEBUG_UTIL_DIRECTION_REQUEST,
+                      tmpl_cmd);
       fiid_template_free (tmpl_cmd);
     }
 }
 
 static void
 _api_ssif_dump_rs (ipmi_ctx_t ctx,
-		   const void *pkt,
-		   unsigned int pkt_len,
-		   uint8_t cmd,
-		   uint8_t net_fn,
-		   uint8_t group_extension,
-		   fiid_obj_t obj_cmd_rs)
+                   const void *pkt,
+                   unsigned int pkt_len,
+                   uint8_t cmd,
+                   uint8_t net_fn,
+                   uint8_t group_extension,
+                   fiid_obj_t obj_cmd_rs)
 {
   fiid_field_t *tmpl_cmd = NULL;
 
   if ((tmpl_cmd = fiid_obj_template (obj_cmd_rs)))
     {
       _api_ssif_dump (ctx,
-		      pkt,
-		      pkt_len,
-		      cmd,
-		      net_fn,
-		      group_extension,
-		      DEBUG_UTIL_DIRECTION_RESPONSE,
-		      tmpl_cmd);
+                      pkt,
+                      pkt_len,
+                      cmd,
+                      net_fn,
+                      group_extension,
+                      DEBUG_UTIL_DIRECTION_RESPONSE,
+                      tmpl_cmd);
       fiid_template_free (tmpl_cmd);
     }
 }
 
 static int
 _ssif_cmd_write (ipmi_ctx_t ctx,
-		 uint8_t cmd,
-		 uint8_t group_extension,
-		 fiid_obj_t obj_cmd_rq)
+                 uint8_t cmd,
+                 uint8_t group_extension,
+                 fiid_obj_t obj_cmd_rq)
 {
   uint8_t *pkt = NULL;
   unsigned int pkt_len;
   int hdr_len, cmd_len, send_len;
   int rv = -1;
-  
+
   assert (ctx
           && ctx->magic == IPMI_CTX_MAGIC
           && fiid_obj_valid (obj_cmd_rq));
-  
+
   if ((hdr_len = fiid_template_len_bytes (tmpl_hdr_kcs)) < 0)
     {
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
     }
-  
+
   if ((cmd_len = fiid_obj_len_bytes (obj_cmd_rq)) < 0)
     {
       API_FIID_OBJECT_ERROR_TO_API_ERRNUM (ctx, obj_cmd_rq);
       goto cleanup;
     }
-  
+
   pkt_len = hdr_len + cmd_len;
-  
+
   if (!(pkt = malloc (pkt_len)))
     {
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
     }
-  memset (pkt, '\0', pkt_len);
-  
+
   if (fill_hdr_ipmi_kcs (ctx->target.lun,
                          ctx->target.net_fn,
                          ctx->io.inband.rq.obj_hdr) < 0)
@@ -211,12 +210,12 @@ _ssif_cmd_write (ipmi_ctx_t ctx,
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
     }
-  
+
   if ((send_len = assemble_ipmi_kcs_pkt (ctx->io.inband.rq.obj_hdr,
                                          obj_cmd_rq,
                                          pkt,
                                          pkt_len,
-					 IPMI_INTERFACE_FLAGS_DEFAULT)) < 0)
+                                         IPMI_INTERFACE_FLAGS_DEFAULT)) < 0)
     {
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
@@ -224,12 +223,12 @@ _ssif_cmd_write (ipmi_ctx_t ctx,
 
   if (ctx->flags & IPMI_FLAGS_DEBUG_DUMP && send_len)
     _api_ssif_dump_rq (ctx,
-		       pkt,
-		       send_len,
-		       cmd,
-		       ctx->target.net_fn,
-		       group_extension,
-		       obj_cmd_rq);
+                       pkt,
+                       send_len,
+                       cmd,
+                       ctx->target.net_fn,
+                       group_extension,
+                       obj_cmd_rq);
 
   if (ipmi_ssif_write (ctx->io.inband.ssif_ctx, pkt, send_len) < 0)
     {
@@ -245,9 +244,9 @@ _ssif_cmd_write (ipmi_ctx_t ctx,
 
 static int
 _ssif_cmd_read (ipmi_ctx_t ctx,
-		uint8_t cmd,
-		uint8_t group_extension,
-		fiid_obj_t obj_cmd_rs)
+                uint8_t cmd,
+                uint8_t group_extension,
+                fiid_obj_t obj_cmd_rs)
 {
   uint8_t *pkt = NULL;
   unsigned int pkt_len;
@@ -255,7 +254,7 @@ _ssif_cmd_read (ipmi_ctx_t ctx,
   fiid_field_t *tmpl = NULL;
   int ret, rv = -1;
   unsigned int intf_flags = IPMI_INTERFACE_FLAGS_DEFAULT;
-  
+
   assert (ctx
           && ctx->magic == IPMI_CTX_MAGIC
           && fiid_obj_valid (obj_cmd_rs));
@@ -268,28 +267,27 @@ _ssif_cmd_read (ipmi_ctx_t ctx,
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
     }
-  
+
   if (!(tmpl = fiid_obj_template (obj_cmd_rs)))
     {
       API_FIID_OBJECT_ERROR_TO_API_ERRNUM (ctx, obj_cmd_rs);
       goto cleanup;
     }
-  
+
   if ((cmd_len = fiid_template_len_bytes (tmpl)) < 0)
     {
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
     }
-  
+
   pkt_len = hdr_len + cmd_len;
-  
+
   if (!(pkt = malloc (pkt_len)))
     {
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
     }
-  memset (pkt, '\0', pkt_len);
-  
+
   if ((read_len = ipmi_ssif_read (ctx->io.inband.ssif_ctx, pkt, pkt_len)) < 0)
     {
       API_SSIF_ERRNUM_TO_API_ERRNUM (ctx, ipmi_ssif_ctx_errnum (ctx->io.inband.ssif_ctx));
@@ -301,21 +299,21 @@ _ssif_cmd_read (ipmi_ctx_t ctx,
       API_SET_ERRNUM (ctx, IPMI_ERR_SYSTEM_ERROR);
       goto cleanup;
     }
-  
+
   if (ctx->flags & IPMI_FLAGS_DEBUG_DUMP && read_len)
     _api_ssif_dump_rs (ctx,
-		       pkt,
-		       read_len,
-		       cmd,
-		       ctx->target.net_fn,
-		       group_extension,
-		       obj_cmd_rs);
+                       pkt,
+                       read_len,
+                       cmd,
+                       ctx->target.net_fn,
+                       group_extension,
+                       obj_cmd_rs);
 
   if ((ret = unassemble_ipmi_kcs_pkt (pkt,
                                       read_len,
                                       ctx->io.inband.rs.obj_hdr,
                                       obj_cmd_rs,
-				      intf_flags)) < 0)
+                                      intf_flags)) < 0)
     {
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
@@ -337,21 +335,21 @@ _ssif_cmd_read (ipmi_ctx_t ctx,
 
 int
 api_ssif_cmd (ipmi_ctx_t ctx,
-	      fiid_obj_t obj_cmd_rq,
-	      fiid_obj_t obj_cmd_rs)
+              fiid_obj_t obj_cmd_rq,
+              fiid_obj_t obj_cmd_rs)
 {
   uint8_t cmd = 0;             /* used for debugging */
   uint8_t group_extension = 0; /* used for debugging */
   uint64_t val;
   struct timespec request, remain;
   uint8_t retry = IPMI_SSIF_RETRY_DEFAULT;
-  
+
   assert (ctx
-	  && ctx->magic == IPMI_CTX_MAGIC
-	  && ctx->type == IPMI_DEVICE_SSIF
-	  && fiid_obj_valid (obj_cmd_rq)
-	  && fiid_obj_packet_valid (obj_cmd_rq) == 1
-	  && fiid_obj_valid (obj_cmd_rs));
+          && ctx->magic == IPMI_CTX_MAGIC
+          && ctx->type == IPMI_DEVICE_SSIF
+          && fiid_obj_valid (obj_cmd_rq)
+          && fiid_obj_packet_valid (obj_cmd_rq) == 1
+          && fiid_obj_valid (obj_cmd_rs));
 
   if (ctx->flags & IPMI_FLAGS_DEBUG_DUMP)
     {
@@ -379,12 +377,12 @@ api_ssif_cmd (ipmi_ctx_t ctx,
   /******************************************************************************
     12.9 SMBus NACKs and Error Recovery:
     ====================================
-    The BMC can NACK the SMBus host controller if it is not ready to accept a new 
-    transaction. Typically, this will be exhibited by the BMC NACK'ing its slave 
-    address. 
-    
-    If the BMC NACKs a single part transaction, software can simply retry it. 
-    If a 'middle' or 'end' transaction is NACK'd, software should not retry the 
+    The BMC can NACK the SMBus host controller if it is not ready to accept a new
+    transaction. Typically, this will be exhibited by the BMC NACK'ing its slave
+    address.
+
+    If the BMC NACKs a single part transaction, software can simply retry it.
+    If a 'middle' or 'end' transaction is NACK'd, software should not retry the
     particular but should restart the multi-part read or write from the beginning
     Start transaction for the transfer.
   *******************************************************************************/
@@ -392,7 +390,7 @@ api_ssif_cmd (ipmi_ctx_t ctx,
     {
       while (1)
         {
-          request.tv_sec = 0; 
+          request.tv_sec = 0;
           request.tv_nsec = IPMI_SSIF_TIMEOUT_DEFAULT;
           if (nanosleep (&request, &remain) < 0 )
             return (-1);
@@ -401,8 +399,8 @@ api_ssif_cmd (ipmi_ctx_t ctx,
             {
               if (retry == 0)
                 return (-1);
-        
-              retry--;        
+
+              retry--;
             }
             else
               break;
@@ -414,7 +412,7 @@ api_ssif_cmd (ipmi_ctx_t ctx,
 
 static int
 _api_ssif_ipmb_send (ipmi_ctx_t ctx,
-		     fiid_obj_t obj_cmd_rq)
+                     fiid_obj_t obj_cmd_rq)
 {
   struct ipmi_ctx_target target_save;
   uint8_t buf[IPMI_MAX_PKT_LEN];
@@ -449,7 +447,7 @@ _api_ssif_ipmb_send (ipmi_ctx_t ctx,
                          ctx->target.net_fn,
                          ctx->target.lun,
                          IPMI_SLAVE_ADDRESS_BMC,
-                         IPMI_BMC_IPMB_LUN_SMS_MSG_LUN,
+                         IPMI_BMC_IPMB_LUN_BMC,
                          ctx->io.inband.rq_seq,
                          obj_ipmb_msg_hdr_rq) < 0)
     {
@@ -460,13 +458,12 @@ _api_ssif_ipmb_send (ipmi_ctx_t ctx,
   if (assemble_ipmi_ipmb_msg (obj_ipmb_msg_hdr_rq,
                               obj_cmd_rq,
                               obj_ipmb_msg_rq,
-			      IPMI_INTERFACE_FLAGS_DEFAULT) < 0)
+                              IPMI_INTERFACE_FLAGS_DEFAULT) < 0)
     {
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
     }
 
-  memset (buf, '\0', IPMI_MAX_PKT_LEN);
   if ((len = fiid_obj_get_all (obj_ipmb_msg_rq,
                                buf,
                                IPMI_MAX_PKT_LEN)) < 0)
@@ -479,15 +476,15 @@ _api_ssif_ipmb_send (ipmi_ctx_t ctx,
   memcpy (&target_save, &ctx->target, sizeof (target_save));
   ctx->target.channel_number_is_set = 0;
   ctx->target.rs_addr_is_set = 0;
-  
+
   ret = ipmi_cmd_send_message (ctx,
-			       target_save.channel_number,
-			       IPMI_SEND_MESSAGE_AUTHENTICATION_NOT_REQUIRED,
-			       IPMI_SEND_MESSAGE_ENCRYPTION_NOT_REQUIRED,
-			       IPMI_SEND_MESSAGE_TRACKING_OPERATION_NO_TRACKING,
-			       buf,
-			       len,
-			       obj_send_cmd_rs);
+                               target_save.channel_number,
+                               IPMI_SEND_MESSAGE_AUTHENTICATION_NOT_REQUIRED,
+                               IPMI_SEND_MESSAGE_ENCRYPTION_NOT_REQUIRED,
+                               IPMI_SEND_MESSAGE_TRACKING_OPERATION_NO_TRACKING,
+                               buf,
+                               len,
+                               obj_send_cmd_rs);
 
   /* restore target info */
   memcpy (&ctx->target, &target_save, sizeof (target_save));
@@ -514,9 +511,9 @@ _api_ssif_ipmb_send (ipmi_ctx_t ctx,
 
 static int
 _api_ssif_ipmb_recv (ipmi_ctx_t ctx,
-		     fiid_obj_t obj_ipmb_msg_hdr_rs,
-		     fiid_obj_t obj_ipmb_msg_trlr,
-		     fiid_obj_t obj_cmd_rs)
+                     fiid_obj_t obj_ipmb_msg_hdr_rs,
+                     fiid_obj_t obj_ipmb_msg_trlr,
+                     fiid_obj_t obj_cmd_rs)
 {
   struct ipmi_ctx_target target_save;
   uint8_t buf[IPMI_MAX_PKT_LEN];
@@ -545,12 +542,12 @@ _api_ssif_ipmb_recv (ipmi_ctx_t ctx,
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
     }
-  
+
   /* get_message will send to the BMC, so clear out target information */
   memcpy (&target_save, &ctx->target, sizeof (target_save));
   ctx->target.channel_number_is_set = 0;
   ctx->target.rs_addr_is_set = 0;
-  
+
   ret = ipmi_cmd_get_message (ctx, obj_get_cmd_rs);
 
   /* restore target info */
@@ -586,7 +583,7 @@ _api_ssif_ipmb_recv (ipmi_ctx_t ctx,
                                 obj_ipmb_msg_hdr_rs,
                                 obj_cmd_rs,
                                 obj_ipmb_msg_trlr,
-				intf_flags) < 0)
+                                intf_flags) < 0)
     {
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
@@ -601,8 +598,8 @@ _api_ssif_ipmb_recv (ipmi_ctx_t ctx,
 
 int
 api_ssif_cmd_ipmb (ipmi_ctx_t ctx,
-		   fiid_obj_t obj_cmd_rq,
-		   fiid_obj_t obj_cmd_rs)
+                   fiid_obj_t obj_cmd_rq,
+                   fiid_obj_t obj_cmd_rs)
 {
   fiid_obj_t obj_ipmb_msg_hdr_rs = NULL;
   fiid_obj_t obj_ipmb_msg_trlr = NULL;
@@ -611,11 +608,11 @@ api_ssif_cmd_ipmb (ipmi_ctx_t ctx,
   int ret, rv = -1;
 
   assert (ctx
-	  && ctx->magic == IPMI_CTX_MAGIC
-	  && ctx->type == IPMI_DEVICE_SSIF
-	  && fiid_obj_valid (obj_cmd_rq)
-	  && fiid_obj_packet_valid (obj_cmd_rq) == 1
-	  && fiid_obj_valid (obj_cmd_rs));
+          && ctx->magic == IPMI_CTX_MAGIC
+          && ctx->type == IPMI_DEVICE_SSIF
+          && fiid_obj_valid (obj_cmd_rq)
+          && fiid_obj_packet_valid (obj_cmd_rq) == 1
+          && fiid_obj_valid (obj_cmd_rs));
 
   if (!(obj_ipmb_msg_hdr_rs = fiid_obj_create (tmpl_ipmb_msg_hdr_rs)))
     {
@@ -638,9 +635,9 @@ api_ssif_cmd_ipmb (ipmi_ctx_t ctx,
   while (1)
     {
       if (_api_ssif_ipmb_recv (ctx,
-			       obj_ipmb_msg_hdr_rs,
-			       obj_ipmb_msg_trlr,
-			       obj_cmd_rs) < 0)
+                               obj_ipmb_msg_hdr_rs,
+                               obj_ipmb_msg_trlr,
+                               obj_cmd_rs) < 0)
         {
           if (ctx->errnum == IPMI_ERR_MESSAGE_TIMEOUT)
             {
@@ -652,8 +649,8 @@ api_ssif_cmd_ipmb (ipmi_ctx_t ctx,
                   goto cleanup;
                 }
 
-	      /* Wait a little bit to avoid spinning */
-	      usleep (IPMI_SSIF_IPMB_REREAD_WAIT);
+              /* Wait a little bit to avoid spinning */
+              usleep (IPMI_SSIF_IPMB_REREAD_WAIT);
               continue;
             }
           goto cleanup;
@@ -715,22 +712,22 @@ api_ssif_cmd_ipmb (ipmi_ctx_t ctx,
 
 int
 api_ssif_cmd_raw (ipmi_ctx_t ctx,
-		  const void *buf_rq,
-		  unsigned int buf_rq_len,
-		  void *buf_rs,
-		  unsigned int buf_rs_len)
+                  const void *buf_rq,
+                  unsigned int buf_rq_len,
+                  void *buf_rs,
+                  unsigned int buf_rs_len)
 {
   fiid_obj_t obj_cmd_rq = NULL;
   fiid_obj_t obj_cmd_rs = NULL;
   int len, rv = -1;
 
   assert (ctx
-	  && ctx->magic == IPMI_CTX_MAGIC
-	  && ctx->type == IPMI_DEVICE_SSIF
-	  && buf_rq
-	  && buf_rq_len
-	  && buf_rs
-	  && buf_rs_len);
+          && ctx->magic == IPMI_CTX_MAGIC
+          && ctx->type == IPMI_DEVICE_SSIF
+          && buf_rq
+          && buf_rq_len
+          && buf_rs
+          && buf_rs_len);
 
   if (!(obj_cmd_rq = fiid_obj_create (tmpl_ssif_raw)))
     {
@@ -752,8 +749,8 @@ api_ssif_cmd_raw (ipmi_ctx_t ctx,
     }
 
   if (api_ssif_cmd (ctx,
-		    obj_cmd_rq,
-		    obj_cmd_rs) < 0)
+                    obj_cmd_rq,
+                    obj_cmd_rs) < 0)
     goto cleanup;
 
   if ((len = fiid_obj_get_all (obj_cmd_rs,
@@ -773,22 +770,22 @@ api_ssif_cmd_raw (ipmi_ctx_t ctx,
 
 int
 api_ssif_cmd_raw_ipmb (ipmi_ctx_t ctx,
-		       const void *buf_rq,
-		       unsigned int buf_rq_len,
-		       void *buf_rs,
-		       unsigned int buf_rs_len)
+                       const void *buf_rq,
+                       unsigned int buf_rq_len,
+                       void *buf_rs,
+                       unsigned int buf_rs_len)
 {
   fiid_obj_t obj_cmd_rq = NULL;
   fiid_obj_t obj_cmd_rs = NULL;
   int len, rv = -1;
 
   assert (ctx
-	  && ctx->magic == IPMI_CTX_MAGIC
-	  && ctx->type == IPMI_DEVICE_SSIF
-	  && buf_rq
-	  && buf_rq_len
-	  && buf_rs
-	  && buf_rs_len);
+          && ctx->magic == IPMI_CTX_MAGIC
+          && ctx->type == IPMI_DEVICE_SSIF
+          && buf_rq
+          && buf_rq_len
+          && buf_rs
+          && buf_rs_len);
 
   if (!(obj_cmd_rq = fiid_obj_create (tmpl_ssif_raw)))
     {
@@ -810,10 +807,10 @@ api_ssif_cmd_raw_ipmb (ipmi_ctx_t ctx,
     }
 
   if (api_ssif_cmd_ipmb (ctx,
-			 obj_cmd_rq,
-			 obj_cmd_rs) < 0)
+                         obj_cmd_rq,
+                         obj_cmd_rs) < 0)
     goto cleanup;
-  
+
   if ((len = fiid_obj_get_all (obj_cmd_rs,
                                buf_rs,
                                buf_rs_len)) < 0)
@@ -821,7 +818,7 @@ api_ssif_cmd_raw_ipmb (ipmi_ctx_t ctx,
       API_FIID_OBJECT_ERROR_TO_API_ERRNUM (ctx, obj_cmd_rs);
       goto cleanup;
     }
-  
+
   rv = len;
  cleanup:
   fiid_obj_destroy (obj_cmd_rq);
