@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2003-2015 FreeIPMI Core Team
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -246,35 +246,35 @@ _ipmi_i2c_smbus_access (ipmi_ssif_ctx_t ctx,
       tv_orig.tv_usec = tv.tv_usec;
 
       if (gettimeofday (&start, NULL) < 0)
-	{
-	  SSIF_ERRNO_TO_SSIF_ERRNUM (ctx, errno);
-	  return (-1);
-	}
+        {
+          SSIF_ERRNO_TO_SSIF_ERRNUM (ctx, errno);
+          return (-1);
+        }
 
       do {
-	if ((n = select (dev_fd + 1,
-			 &read_fds,
-			 NULL,
-			 NULL,
-			 &tv)) < 0)
-	  {
-	    if (errno != EINTR)
-	      {
-		SSIF_ERRNO_TO_SSIF_ERRNUM (ctx, errno);
-		return (-1);
-	      }
+        if ((n = select (dev_fd + 1,
+                         &read_fds,
+                         NULL,
+                         NULL,
+                         &tv)) < 0)
+          {
+            if (errno != EINTR)
+              {
+                SSIF_ERRNO_TO_SSIF_ERRNUM (ctx, errno);
+                return (-1);
+              }
 
-	    if (gettimeofday (&end, NULL) < 0)
-	      {
-		SSIF_ERRNO_TO_SSIF_ERRNUM (ctx, errno);
-		return (-1);
-	      }
+            if (gettimeofday (&end, NULL) < 0)
+              {
+                SSIF_ERRNO_TO_SSIF_ERRNUM (ctx, errno);
+                return (-1);
+              }
 
-	    /* delta = end - start */
-	    timersub (&end, &start, &delta);
-	    /* tv = tv_orig - delta */
-	    timersub (&tv_orig, &delta, &tv);
-	  }
+            /* delta = end - start */
+            timersub (&end, &start, &delta);
+            /* tv = tv_orig - delta */
+            timersub (&tv_orig, &delta, &tv);
+          }
       } while (n < 0);
 
       if (!n)
@@ -483,18 +483,20 @@ ipmi_ssif_ctx_create (void)
       ERRNO_TRACE (errno);
       return (NULL);
     }
-  memset (ctx, '\0', sizeof (struct ipmi_ssif_ctx));
 
   ctx->magic = IPMI_SSIF_CTX_MAGIC;
+  ctx->driver_device = NULL;
+  ctx->driver_address = IPMI_DEFAULT_SSIF_IPMB_ADDR;
+  ctx->flags = IPMI_SSIF_FLAGS_DEFAULT;
+  ctx->device_fd = -1;
+  ctx->io_init = 0;
+  ctx->semid = -1;
+
   if (!(ctx->driver_device = strdup (IPMI_DEFAULT_I2C_DEVICE)))
     {
       ERRNO_TRACE (errno);
       goto cleanup;
     }
-  ctx->driver_address = IPMI_DEFAULT_SSIF_IPMB_ADDR;
-  ctx->flags = IPMI_SSIF_FLAGS_DEFAULT;
-  ctx->device_fd = -1;
-  ctx->io_init = 0;
 
   if ((ctx->semid = driver_mutex_init ()) < 0)
     {
@@ -891,8 +893,6 @@ _ipmi_ssif_cmd_write (ipmi_ssif_ctx_t ctx,
       goto cleanup;
     }
 
-  memset (pkt, 0, pkt_len);
-
   if (fill_hdr_ipmi_kcs (lun,
                          net_fn,
                          obj_hdr) < 0)
@@ -905,7 +905,7 @@ _ipmi_ssif_cmd_write (ipmi_ssif_ctx_t ctx,
                              obj_cmd_rq,
                              pkt,
                              pkt_len,
-			     IPMI_INTERFACE_FLAGS_DEFAULT) < 0)
+                             IPMI_INTERFACE_FLAGS_DEFAULT) < 0)
     {
       SSIF_SET_ERRNUM (ctx, IPMI_SSIF_ERR_INTERNAL_ERROR);
       goto cleanup;
@@ -967,8 +967,6 @@ _ipmi_ssif_cmd_read (ipmi_ssif_ctx_t ctx,
       goto cleanup;
     }
 
-  memset (pkt, 0, pkt_len);
-
   if ((read_len = ipmi_ssif_read (ctx,
                                   pkt,
                                   pkt_len)) < 0)
@@ -984,7 +982,7 @@ _ipmi_ssif_cmd_read (ipmi_ssif_ctx_t ctx,
                                       read_len,
                                       obj_hdr,
                                       obj_cmd_rs,
-				      IPMI_INTERFACE_FLAGS_DEFAULT)) < 0)
+                                      IPMI_INTERFACE_FLAGS_DEFAULT)) < 0)
     {
       SSIF_SET_ERRNUM (ctx, IPMI_SSIF_ERR_INTERNAL_ERROR);
       goto cleanup;
