@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2003-2014 FreeIPMI Core Team
- * 
+ * Copyright (C) 2003-2015 FreeIPMI Core Team
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifndef FIID_H
@@ -58,7 +58,7 @@ enum fiid_err
     FIID_ERR_INTERNAL_ERROR                  = 24,
     FIID_ERR_ERRNUMRANGE                     = 25
   };
-  
+
 typedef enum fiid_err fiid_err_t;
 
 /*
@@ -136,6 +136,7 @@ typedef enum fiid_err fiid_err_t;
     || FIID_FIELD_LENGTH_FLAG (__flags) ==  FIID_FIELD_LENGTH_VARIABLE) ? 1 : 0)
 
 #define FIID_FIELD_MAKES_PACKET_SUFFICIENT 0x00010000
+#define FIID_FIELD_SECURE_MEMSET_ON_CLEAR  0x00100000
 
 /*
  * fiid_field_t
