@@ -252,7 +252,7 @@ int ipmi_fru_multirecord_dc_load (ipmi_fru_ctx_t ctx,
                                   const void *areabuf,
                                   unsigned int areabuflen,
                                   unsigned int *output_number,
-                                  unsigned int *standby,
+                                  unsigned int *standby, /* ignored */
                                   int *nominal_voltage,
                                   int *specd_minimum_voltage,
                                   int *specd_maximum_voltage,
@@ -309,7 +309,7 @@ int ipmi_fru_multirecord_extended_dc_load (ipmi_fru_ctx_t ctx,
                                            unsigned int areabuflen,
                                            unsigned int *output_number,
                                            unsigned int *current_units,
-                                           unsigned int *standby,
+                                           unsigned int *standby, /* ignored */
                                            int *nominal_voltage,
                                            int *specd_minimum_voltage,
                                            int *specd_maximum_voltage,
