@@ -240,10 +240,129 @@ const char * const ipmi_oem_intel_s2600jf_specific_qpi_link_width_reduced[] =
   };
 unsigned int ipmi_oem_intel_s2600jf_specific_qpi_link_width_reduced_max_index = 0x02;
 
+/*
+ * Intel S2600WP
+ */
+
+/* achu: Similar to above, but some events text changed and new ones,
+ * so new arrays to differentiate */
+
+const char * const ipmi_oem_intel_s2600wp_specific_pcie_fatal_error[] =
+  {
+    "Data Link Layer Protocol Error",
+    "Surprise Link Down Error",
+    "Completer Abort",
+    "Unsupported Request",
+    "Poisoned TLP",
+    "Flow Control Protocol",
+    "Completion Timeout",
+    "Receiver Buffer Overflow",
+    "ACS Violation Error",
+    "Malformed TLP Error",
+    "ECRC Error",
+    "Received Fatal Message From Downstream",
+    "Unexpected Completion",
+    "Received ERR_NONFATAL Message",
+    "Uncorrectable Internal",
+    "MC Blocked TLP",
+    NULL
+  };
+unsigned int ipmi_oem_intel_s2600wp_specific_pcie_fatal_error_max_index = 0x0F;
+
+const char * const ipmi_oem_intel_s2600wp_specific_pcie_fatal_error_2[] =
+  {
+    "Atomic Egress Blocked",
+    "TLP Prefix Blocked",
+    "reserved",
+    "reserved",
+    "reserved",
+    "reserved",
+    "reserved",
+    "reserved",
+    "reserved",
+    "reserved",
+    "reserved",
+    "reserved",
+    "reserved",
+    "reserved",
+    "reserved",
+    "Unspecified Non-AER Fatal Error",
+    NULL
+  };
+unsigned int ipmi_oem_intel_s2600wp_specific_pcie_fatal_error_2_max_index = 0x0F;
+
+const char * const ipmi_oem_intel_s2600wp_specific_pcie_correctable_error[] =
+  {
+    "Receiver Error",
+    "Bad DLLP",
+    "Bad TLP",
+    "Replay Num Rollover",
+    "Replay Timer timeout",
+    "Advisory Non-fatal",
+    "Link BW Changed",
+    "Correctable Internal",
+    "Header Log Overflow",
+    NULL
+  };
+unsigned int ipmi_oem_intel_s2600wp_specific_pcie_correctable_error_max_index = 0x08;
+
+const char * const ipmi_oem_intel_s2600wp_specific_qpi_fatal_error[] =
+  {
+    "Link Layer Uncorrectable ECC Error",
+    "Protocol Layer Poisoned Packet Reception Error",
+    "LINK/PHY Init Failure with resultant degradation in link width",
+    "CSI PHY Layer detected drift buffer alarm",
+    "CSI PHY detected latency buffer rollover",
+    "CSI PHY Init Failure",
+    "CSI Link Layer generic control error (buffer overflow/underflow, credit underflow and so on.)",
+    "Parity error in link or PHY layer",
+    "Protocol layer timeout detected",
+    "Protocol layer failed response",
+    "Protocol layer illegal packet field, target Node ID and so on.",
+    "Protocol Layer Queue/table overflow/underflow",
+    "Viral Error",
+    "Protocol Layer parity error",
+    "Routing Table Error",
+    NULL
+  };
+unsigned int ipmi_oem_intel_s2600wp_specific_qpi_fatal_error_max_index = 0x0E;
+
+const char * const ipmi_oem_intel_s2600wp_specific_qpi_fatal_error_2[] =
+  {
+    "Illegal inbound request",
+    "IIO Write Cache Uncorrectable Data ECC Error",
+    "IIO CSR crossing 32-bit boundary Error",
+    "IIO Received XPF physical/logical redirect interrupt inbound",
+    "IIO Illegal SAD or Illegal or non-existent address or memory",
+    "IIO Write Cache Coherency Violation",
+    NULL
+  };
+unsigned int ipmi_oem_intel_s2600wp_specific_qpi_fatal_error_2_max_index = 0x05;
+
+const char * const ipmi_oem_intel_s2600wp_specific_qpi_link_width_reduced[] =
+  {
+    "reserved",
+    "Reduced to 1/2 width",
+    "Reduced to 1/4 width",
+    NULL
+  };
+unsigned int ipmi_oem_intel_s2600wp_specific_qpi_link_width_reduced_max_index = 0x02;
+
+const char * const ipmi_oem_intel_s2600wp_specific_firmware_update_status_sensor[] =
+  {
+    "Update started",
+    "Update completed successfully",
+    "Update failure",
+    NULL
+  };
+
+unsigned int ipmi_oem_intel_s2600wp_specific_firmware_update_status_sensor_max_index = 0x02;
+
 /*
  * Intel S2600KP
  * Intel S2600WT2
  * Intel S2600WTT
+ * Intel S2600GZ
  */
 
 const char * const ipmi_oem_intel_e52600v3_specific_qpi_fatal_error[] =
